ABlog for Sphinx
================

|Build Status|

.. |Build Status| image:: https://dev.azure.com/sunpy/ablog/_apis/build/status/sunpy.ablog?repoName=sunpy%2Fablog&branchName=main
   :target: https://dev.azure.com/sunpy/ablog/_build/latest?definitionId=17&repoName=sunpy%2Fablog&branchName=main

Note
----

Please note that is an official new home of `Ahmet Bakan's Ablog Sphinx extension <https://github.com/abakan/ablog/>`__.
This version is maintained with the aim to keep it working for SunPy's website and thus new features are **highly unlikely**.

ABlog
-----

ABlog is a Sphinx extension that converts any documentation or personal website project into a full-fledged blog

`Please check our documentation for information on how to get started. <https://ablog.readthedocs.io/>`__
